(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     17673,        423]*)
(*NotebookOutlinePosition[     18346,        446]*)
(*  CellTagsIndexPosition[     18302,        442]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Die Baker-Campbell-Hausdorff Reihe und das Zassenhaus Produkt\
\>", "Title"],

Cell[TextData[{
  "In diesem Notebook werden die Folgeglieder der Baker-Campbell-Hausdorff \
Reihe sowie des Zassenhaus Produktes f\[UDoubleDot]r nat\[UDoubleDot]rliche \
Zahlen ",
  StyleBox["n>1", "Input"],
  " berechnet. Als Grundlagen f\[UDoubleDot]r die Bake-Campbell-Hausdorff \
Reihe dienten vor allem das Artikel von Reinsch [siehe Literaturliste]."
}], "Text"],

Cell[CellGroupData[{

Cell["Die Baker-Campbell-Hausdorff Reihe", "Section"],

Cell[TextData[{
  "Die folgende Funktion berechnet das ",
  StyleBox["n", "Input"],
  "te Folgenglied der Baker-Campbell-Hausdorff Reihe und gibt dieses als Term \
zur\[UDoubleDot]ck."
}], "Text"],

Cell[BoxData[
    \(\(BCH[n_, x_, y_]\  := \ 
        Module[{F, \ G, \ B, \ A, \ T, \ s, \ r, \ i, \ j, \ 
            k}, \[IndentingNewLine]F\  = \ 
            Table[1/\(\((j - i)\)!\), \ {i, n + 1}, {j, 
                n + 1}]; \[IndentingNewLine]G\  = \ 
            Table[1/\(\((j - i)\)!\)*Product[s[k], {k, i, j - 1}], \ {i, 
                n + 1}, {j, n + 1}]; \[IndentingNewLine]B\  = \ 
            IdentityMatrix[n + 1]; \[IndentingNewLine]A\  = \ 
            F . G - B; \[IndentingNewLine]\[IndentingNewLine]T\  = \ 
            Expand[\(-\(Sum[B = \(-B . A\); \ B/k, \ {k, n}]\)[\([1, 
                      n + 1]\)]\)*
                Product[
                  s[k], {k, 
                    n}]]; \[IndentingNewLine]\[IndentingNewLine]Sum[\
\[IndentingNewLine]r\  = \ \((\ 
                  List\  @@ \ \ T[\([k]\)])\) /. \ {s[i_] \[Rule] \ 
                    ToString[x], \ 
                  s[i_]^2\  \[Rule] 
                    ToString[
                      y]}; \[IndentingNewLine]r[\([1]\)]*\((StringJoin\  @@ \ 
                  Take[r, \(-n\)])\), \[IndentingNewLine]{k, 
              Length[T]}\[IndentingNewLine]]\[IndentingNewLine]];\)\)], \
"Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BCH[5, x, y]\)], "Input"],

Cell[BoxData[
    \(\(-\("xxxxy"\/720\)\) + "xxxyx"\/180 + "xxxyy"\/180 - "xxyxx"\/120 - 
      "xxyxy"\/120 - "xxyyx"\/120 + "xxyyy"\/180 + "xyxxx"\/180 - 
      "xyxxy"\/120 + "xyxyx"\/30 - "xyxyy"\/120 - "xyyxx"\/120 - 
      "xyyxy"\/120 + "xyyyx"\/180 - "xyyyy"\/720 - "yxxxx"\/720 + 
      "yxxxy"\/180 - "yxxyx"\/120 - "yxxyy"\/120 - "yxyxx"\/120 + 
      "yxyxy"\/30 - "yxyyx"\/120 + "yxyyy"\/180 + "yyxxx"\/180 - 
      "yyxxy"\/120 - "yyxyx"\/120 - "yyxyy"\/120 + "yyyxx"\/180 + 
      "yyyxy"\/180 - "yyyyx"\/720\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Die Baker-Campbell-Hausdorff Reihe in Kommutatorschreibweise", "Section"],

Cell[TextData[{
  "Diese Funktion schreibt das ",
  StyleBox["n", "Input"],
  "te Folgenglied der Baker-Campbell-Hausdorff Reihe in eine \
\[UDoubleDot]bliche Kommutatorschreibweise um. Dabei wurde die Vermutung \
verwendet, die auch schon von Dynkin aufgestellt wurde."
}], "Text"],

Cell[BoxData[
    \(\(BCHcom[n_]\  := \ 
        Module[{A, B, s, t, i}, \[IndentingNewLine]A\  = \ 
            List\  @@ \ BCH[n, x, y]; \[IndentingNewLine]t\  = \ 
            StringReplace[
              StringTake[A[\([1, 2]\)], \ 
                n - 2], \ {"\<x\>" \[Rule] "\<]\>", "\<y\>" \[Rule] \
"\<]\>"}]; \[IndentingNewLine]\[IndentingNewLine]Sum[\[IndentingNewLine]B\  = \
\ List\  @@ \ A[\([i]\)]; \[IndentingNewLine]If\ [\ \((StringTake[
                    B[\([2]\)], \ 
                    2]\  \[Equal] \ "\<yx\>")\)\ , \[IndentingNewLine]s\  = \ 
                StringReplace[
                    StringReverse[
                      B[\([2]\)]], \ {"\<x\>" \[Rule] "\<[x,\>", "\<y\>" \
\[Rule] "\<[y,\>"}] <> "\<-\>"; \[IndentingNewLine]s\  = \ 
                StringReplace[
                    s, \ {"\<[x,-\>" \[Rule] "\<x]\>", "\<[y,-\>" \[Rule] \
"\<y]\>"}] <> t; \[IndentingNewLine]\((\(-1\))\)^\((n - 1)\)\ B[\([1]\)]/
                  StringCount[B[\([2]\)], "\<y\>"]\ *
                s, \[IndentingNewLine]0], \[IndentingNewLine]{i, 
              Length[A]}\[IndentingNewLine]]\[IndentingNewLine]];\)\)], \
"Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BCHcom[5]\)], "Input"],

Cell[BoxData[
    \(\(-\("[x,[x,[x,[x,y]]]]"\/720\)\) - "[x,[x,[y,[x,y]]]]"\/240 - 
      "[x,[y,[x,[x,y]]]]"\/240 - "[x,[y,[y,[x,y]]]]"\/360 + 
      "[y,[x,[x,[x,y]]]]"\/360 + "[y,[x,[y,[x,y]]]]"\/90 - 
      "[y,[y,[x,[x,y]]]]"\/360 + "[y,[y,[y,[x,y]]]]"\/720\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Das Zassenhaus Produkt", "Section"],

Cell[TextData[{
  "Die folgende Funktion berechnet das ",
  StyleBox["n", "Input"],
  "te Folgenglied des Zassenhaus Produktes und gibt dieses als Term zur\
\[UDoubleDot]ck."
}], "Text"],

Cell[BoxData[
    \(\(ZH[n_, a_, b_]\  := \ 
        Module[{C, \ L, \ K, \ J, \ P, \ Q, \ m, \ t, \ r, \ i, \ j, \ k, \ 
            u, \ z}, \[IndentingNewLine]m = 
            2; \[IndentingNewLine]NestList[\((\ \(m++\); \[IndentingNewLine]L\
\  = \ Table[\((\(-1\))\)^\((i + j)\)/\(\((j - i)\)!\)*
                      Product[t[k], {k, i, j - 1}], \ {i, m + 1}, {j, 
                      m + 1}]; \[IndentingNewLine]K\  = \ 
                  Table[\((\(-1\))\)^\((i + j)\)/\(\((j - i)\)!\), \ {i, 
                      m + 1}, {j, m + 1}]; \[IndentingNewLine]J\  = \ 
                  Table[1/\(\((j - i)\)!\)*
                      Product[\((1 + t[k])\), {k, i, j - 1}], \ {i, 
                      m + 1}, {j, m + 1}]; \[IndentingNewLine]P\  = \ 
                  Table[KroneckerDelta[i + 1, j], {i, m + 1}, {j, 
                      m + 1}]; \[IndentingNewLine]Q\  = \ 
                  Table[KroneckerDelta[i + 1, j]*t[i], {i, m + 1}, {j, 
                      m + 1}]; \[IndentingNewLine]\[IndentingNewLine]C[
                    m]\  = \ 
                  Expand[\[IndentingNewLine]\((\((Dot\  @@ \ 
                                Table[
                                  MatrixExp[\(-Sum[
                                        r = \((List\  @@ \ \(C[
                                        m - u]\)[\([z]\)])\) /. {t[
                                        i_] \[Rule] P, 
                                        t[i_]^2 \[Rule] 
                                        Q}; \[IndentingNewLine]r[\([1]\)]*\((\
Dot @@ \ Take[r, \(-Length[r]\) + 1])\), {z, Length[C[m - u]]}]\)], {u, 
                                    m - 2}]\ )\) . L . K . J)\)[\([1, 
                          m + 1]\)]*
                      Product[t[j]\ , {j, m}]\ ])\) &, \[IndentingNewLine]C[
                2]\  = \ \((t[1]^2\ t[2])\)/2 - \((t[1]\ t[2]^2)\)/2, 
            n - 2]; \[IndentingNewLine]\[IndentingNewLine]\ 
          Sum[\[IndentingNewLine]r\  = \ \((\ 
                  List\  @@ \ \ \(C[n]\)[\([k]\)])\) /. \ {t[i_] \[Rule] \ 
                    ToString[a], \ 
                  t[i_]^2\  \[Rule] 
                    ToString[
                      b]}; \[IndentingNewLine]r[\([1]\)]*\((StringJoin\  @@ \ 
                  Take[r, \(-n\)])\), \[IndentingNewLine]{k, 
              Length[C[
                  n]]}\[IndentingNewLine]]\[IndentingNewLine]];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ZH[4, a, b]\)], "Input"],

Cell[BoxData[
    \(\(-\("aaab"\/24\)\) + "aaba"\/8 + "aabb"\/8 - "abaa"\/8 - "abab"\/4 - 
      "abbb"\/8 + "baaa"\/24 + "baba"\/4 + \(3\ "babb"\)\/8 - 
      "bbaa"\/8 - \(3\ "bbab"\)\/8 + "bbba"\/8\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Das Zassenhaus Produkt in Kommutatorschreibweise", "Section"],

Cell[TextData[{
  "Die folgende Funktion gibt das ",
  StyleBox["n", "Input"],
  "te Folgeglied des Zassenhaus Produktes in Kommutatorschreibweise zur\
\[UDoubleDot]ck. Auch dabei wurde unsere Vermutung verwendet."
}], "Text"],

Cell[BoxData[
    \(\(ZHcom[n_]\  := \ 
        Module[{A, B, s, t, i}, \[IndentingNewLine]A\  = \ 
            List\  @@ \ ZH[n, a, b]; \[IndentingNewLine]t\  = \ 
            StringReplace[
              StringTake[A[\([1, 2]\)], \ 
                n - 2], \ {"\<a\>" \[Rule] "\<[\>", "\<b\>" \[Rule] \
"\<[\>"}]; \[IndentingNewLine]\[IndentingNewLine]Sum[\[IndentingNewLine]B\  = \
\ List\  @@ \ A[\([i]\)]; \[IndentingNewLine]If\ [\ \((StringTake[
                    B[\([2]\)], \ 
                    2]\  \[Equal] \ "\<ba\>")\)\ , \[IndentingNewLine]s\  = \ \
"\<-\>" <> StringReplace[
                    B[\([2]\)], \ {"\<a\>" \[Rule] "\<,a]\>", "\<b\>" \[Rule] \
"\<,b]\>"}]; \[IndentingNewLine]s\  = \ 
                t <> StringReplace[
                    s, \ {"\<-,a]\>" \[Rule] "\<[a\>", "\<-,b]\>" \[Rule] \
"\<[b\>"}]; \[IndentingNewLine]B[\([1]\)]/StringCount[B[\([2]\)], "\<b\>"]\ *
                s, \[IndentingNewLine]0], \[IndentingNewLine]{i, 
              Length[A]}\[IndentingNewLine]]\[IndentingNewLine]];\)\)], \
"Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ZHcom[6]\)], "Input"],

Cell[BoxData[
    \("[[[[[b,a],a],a],a],a]"\/720 + "[[[[[b,a],a],b],b],b]"\/288 + 
      "[[[[[b,a],b],a],a],a]"\/144 - "[[[[[b,a],b],a],b],b]"\/96 + 
      "[[[[[b,a],b],b],a],a]"\/72 + "[[[[[b,a],b],b],b],a]"\/48 + 
      "[[[[[b,a],b],b],b],b]"\/144\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Das q-Zassenhaus Produkt", "Section"],

Cell[TextData[{
  "Die folgende Funktion berechnet das ",
  StyleBox["n", "Input"],
  "te Folgenglied des Zassenhaus Produktes mit der verallgemeinerten \
q-Exponentialfunktion."
}], "Text"],

Cell[BoxData[{
    \(\(\(k[n_, q_]\  := \ 
        Module[{i}, \ Sum[q^i, {i, 0, n - 1}]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(kf[n_, q_]\  := \ 
        Module[{i}, \ Product[k[i, q], {i, 1, n}]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Eq[n_, X_, q_]\  := \ 
        Module[{A, i}, \[IndentingNewLine]A\  = \ 
            X; \[IndentingNewLine]IdentityMatrix[n + 1] + X + 
            Sum[A = A . X; \ 
              A/kf[i, q], {i, 2, 
                n}]\[IndentingNewLine]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(ZHq[n_, a_, b_, q_, A_]\  := \ 
        Module[{C, \ L, \ K, \ J, \ P, \ Q, \ m, \ t, \ r, \ i, \ j, \ k, \ 
            u, \ z}, \[IndentingNewLine]m = 
            2; \[IndentingNewLine]NestList[\((\ \(m++\); \[IndentingNewLine]P\
\  = \ Table[KroneckerDelta[i + 1, j], {i, m + 1}, {j, 
                      m + 1}]; \[IndentingNewLine]Q\  = \ 
                  Table[KroneckerDelta[i + 1, j]*t[i], {i, m + 1}, {j, 
                      m + 1}]; \[IndentingNewLine]\[IndentingNewLine]C[
                    m]\  = \ 
                  Expand[\((\((Dot @@ 
                                Table[
                                  Inverse[
                                    Eq[m, 
                                      Sum[r = \((List @@ \(C[
                                        m - u]\)[\([z]\)])\) /. {t[
                                        i_] \[Rule] P, 
                                        t[i_]^2 \[Rule] 
                                        Q}; \[IndentingNewLine]Product[
                                        r[\([i]\)], {i, 
                                        Length[r] - \((m - u)\)}]*\((Dot @@ 
                                        Take[r, \(-\((m - u)\)\)])\), {z, 
                                        Length[C[m - u]]}], 
                                      q^\((A[\([m - u - 1]\)])\)]], {u, 
                                    m - 2}])\) . \((Inverse[Eq[m, Q, q]] . 
                                Inverse[Eq[m, P, q]] . 
                                Eq[m, P + Q, q])\))\)[\([1, m + 1]\)]*
                      Product[t[j]\ , {j, m}]\ ])\) &, \[IndentingNewLine]C[
                2]\  = \ \((t[1]^2\ t[2])\)/\((1 + q)\) - 
                q\ \((t[1]\ t[2]^2)\)/\((1 + q)\), \ 
            n - 2]; \[IndentingNewLine]\[IndentingNewLine]Sum[
            r = \((List @@ \(C[n]\)[\([k]\)])\) /. {t[i_] \[Rule] 
                    ToString[a], 
                  t[i_]^2 \[Rule] ToString[b]}; \[IndentingNewLine]Product[
                r[\([i]\)], {i, Length[r] - n}]*\((StringJoin @@ 
                  Take[r, \(-n\)])\), {k, 
              Length[C[
                  n]]}\[IndentingNewLine]]\[IndentingNewLine]];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ZHq[3, a, b, q, {a[2], a[3], a[4], a[5], a[6]}]\)], "Input"],

Cell[BoxData[
    \("aab" + "bab" - \(2\ "aab"\)\/\(1 + q\) - "aba"\/\(1 + q\) - 
      "abb"\/\(1 + q\) - "bab"\/\(1 + q\) - "bba"\/\(1 + q\) + 
      "aab"\/\(\((1 + q)\)\ \((1 + q + q\^2)\)\) + 
      "aba"\/\(\((1 + q)\)\ \((1 + q + q\^2)\)\) + 
      "abb"\/\(\((1 + q)\)\ \((1 + q + q\^2)\)\) + 
      "baa"\/\(\((1 + q)\)\ \((1 + q + q\^2)\)\) + 
      "bab"\/\(\((1 + q)\)\ \((1 + q + q\^2)\)\) + 
      "bba"\/\(\((1 + q)\)\ \((1 + q + q\^2)\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Literaturliste", "Section"],

Cell[TextData[{
  "[1]   Cigler, J. (1982): ''Elementare q-Identit\[ADoubleDot]ten''. \
Seminaire Lotharingien de Combinatoire 182, 261-267. Online version: ",
  Cell[BoxData[
      FormBox[
        ButtonBox[\(\(\(http\)\(:\)\) // \(homepage . univie . ac . at/
                johann . cigler\)/s05cigler . pdf\),
          ButtonData:>{
            URL[ "http://homepage.univie.ac.at/johann.cigler/s05cigler.pdf"], 
            None},
          ButtonStyle->"Hyperlink"], TraditionalForm]]],
  ".\n\n[2]   Dynkin, E.B. (1949): ''On the representation by means of \
commutators of the series log(e^xe^y) for noncommuting x,y''. Mathematic \
Mathematicheskii 67, 155-162. In russisch.\n\n[3]   Goldberg, K. (1956): \
''The formal power series for log(e^xe^y)''. Duke Mathematical Journal 23, \
13-21.\n  \n[4]   Klarsfeld, S., Oteo, J.A. (1989): ''The \
Baker-Campbell-Hausdorff formula and the convergence of the Magnus \
expansion''. Journal of Physics 22, 4565-4572.\n\n[5]   Magnus, W. (1954): \
''On the Exponential Solution of Differential Equations for a Linear \
Operator''. Communications on Pure and Applied Mathematics, Volume VII, \
649-673.\n\n[6]   Oteo, J.A. (1991): ''The Baker-Campbell-Hausdorff formula \
and nested commuator identities''. Journal of Mathematical Physics 32, \
419-424.\n\n[7]   Quesne, C. (2004): ''Disentangling q-Exponentials: A \
General Approach''. International Journal of Theoretical Physics 43, 545-559. \
Online version: ",
  ButtonBox["http://arxiv.org/abs/math-ph/0310038",
    ButtonData:>{
      URL[ "http://arxiv.org/abs/math-ph/0310038"], None},
    ButtonStyle->"Hyperlink"],
  ".\n\n[8]   Reinsch, M.W. (2000): ''A simple expression for the terms in \
the Baker-Campbell-Hausdorff series''. Journal of Mathematical Physics 41, \
2434-2442. Online version: ",
  ButtonBox["http://arxiv.org/abs/math-ph/9905012/",
    ButtonData:>{
      URL[ "http://arxiv.org/abs/math-ph/9905012/"], None},
    ButtonStyle->"Hyperlink"],
  ".\n\n[9]   Sridhar, R., Jagannathan R. (2002). ''On the q-analogues of the \
Zassenhaus formula for disentangling exponential operators''. Journal of \
Computational and Applied Mathematics 160, 297-305. Online version: ",
  ButtonBox["http://arxiv.org/PS_cache/math-ph/pdf/0212/0212068.pdf",
    ButtonData:>{
      URL[ "http://arxiv.org/PS_cache/math-ph/pdf/0212/0212068.pdf"], None},
    ButtonStyle->"Hyperlink"],
  ".\n\n[10]   Weisstein, E.W. (2004): \"Baker-Campbell-Hausdorff Series\". A \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Notebook. Online version: ",
  ButtonBox["http://mathworld.wolfram.com/Baker-Campbell-HausdorffSeries.html.\
",
    ButtonData:>{
      URL[ 
      "http://mathworld.wolfram.com/Baker-Campbell-HausdorffSeries.html"], 
      None},
    ButtonStyle->"Hyperlink"],
  "\n\n[11]   Wilcox, R.M. (1966): ''Exponential Operators and Parameter \
Differentiation in Quantum Physics''. Journal of Mathematical Physics 8, \
962-982."
}], "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowSize->{1016, 668},
WindowMargins->{{0, Automatic}, {Automatic, -19}},
CellLabelAutoDelete->True
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 86, 2, 150, "Title"],
Cell[1865, 57, 369, 7, 53, "Text"],

Cell[CellGroupData[{
Cell[2259, 68, 53, 0, 73, "Section"],
Cell[2315, 70, 196, 5, 34, "Text"],
Cell[2514, 77, 1191, 23, 290, "Input"],

Cell[CellGroupData[{
Cell[3730, 104, 45, 1, 30, "Input"],
Cell[3778, 107, 537, 8, 71, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4364, 121, 79, 0, 73, "Section"],
Cell[4446, 123, 282, 6, 53, "Text"],
Cell[4731, 131, 1152, 21, 290, "Input"],

Cell[CellGroupData[{
Cell[5908, 156, 42, 1, 30, "Input"],
Cell[5953, 159, 276, 4, 76, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6278, 169, 41, 0, 73, "Section"],
Cell[6322, 171, 186, 5, 34, "Text"],
Cell[6511, 178, 2397, 40, 430, "Input"],

Cell[CellGroupData[{
Cell[8933, 222, 44, 1, 30, "Input"],
Cell[8980, 225, 214, 3, 42, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9243, 234, 67, 0, 73, "Section"],
Cell[9313, 236, 226, 5, 34, "Text"],
Cell[9542, 243, 1052, 19, 290, "Input"],

Cell[CellGroupData[{
Cell[10619, 266, 41, 1, 30, "Input"],
Cell[10663, 269, 266, 4, 76, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10978, 279, 43, 0, 73, "Section"],
Cell[11024, 281, 190, 5, 34, "Text"],
Cell[11217, 288, 2798, 50, 490, "Input"],

Cell[CellGroupData[{
Cell[14040, 342, 80, 1, 30, "Input"],
Cell[14123, 345, 468, 8, 80, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[14640, 359, 33, 0, 73, "Section"],
Cell[14676, 361, 2969, 58, 470, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

